#!/bin/sh


#
#  Shell script to delete/initialize Derby objects for the DVD
#  databases.
#
#  Make a copy of this script and enter your own values for the
#  passwords.  Be careful, as this will delete all traces of the
#  DVD application from the engine and redefine empty tables.
#
#  This script needs to be run under an ID to which the
#  $DERBY_DATA directory defined below is writable; this would
#  usually be the ID under which you run Derby.  Also, it must
#  be run from a directory which is writable to this ID, since
#  ij will attempt to write a "derby.log" file there.
#


#
#  ***NOTE***
#  I was unable to get Derby to configure properly by defining
#  dvd as a database-level userid; I had to define it in
#  derby.properties as a system-level ID.
#
#  Also, I needed to define a DVD SCHEMA since it seems to
#  be assumed.  Once I did that, issuing GRANTs for dvd on
#  DVD received errors, and in fact were not needed.
#


#
#  Set the following to the Derby install directory and the
#  directory that the Derby Network Server uses as its working
#  directory (which is where it keeps database directories).
#

DERBY_HOME=/usr/local/derby
export DERBY_HOME
DERBY_DATA=$DERBY_HOME/data


#
#  Set the following to the userid and password for the Derby
#  administrator account.
#

ROOT_USER=sa
ROOT_PASSWORD=password


#
#  Set the following to the desired password for the "dvd"
#  account.  This must have escaped single quotes around it
#  so that ij will find them below; if they were coded
#  explicitly below, then the shell wouldn't substitute for
#  the password.
#

DVD_PASSWORD=\'dvd\'


#
#  Derby sets its own CLASSPATH, but won't if it finds one
#  going in.
#

CLASSPATH=
export CLASSPATH


#
#  Create the ij properties file.
#

cat >/tmp/ij.properties <<EOF1
ij.user = $ROOT_USER
ij.password = $ROOT_PASSWORD
ij.protocol = jdbc:derby://localhost:1527/
EOF1


#
#  Delete any existing database.  Derby has no DROP DATABASE
#  command; you delete a database by deleting the directory
#  of the same name.
#

rm -fR $DERBY_DATA/DVD


#
#  Run the batch commands.  Derby has no CREATE DATABASE command;
#  you create a database by trying to connect to it with the
#  "create=true" attribute.  You create users for a database
#  by setting a property of derby.user.(userid) to the value
#  you want as a password (this is for Derby BUILTIN users;
#  if you're using LDAP or something else, remove this and
#  define the dvd user elsewhere).
#

/bin/ksh $DERBY_HOME/bin/ij -p /tmp/ij.properties <<EOF2
Connect 'DVD;create=true';
CALL SYSCS_UTIL.SYSCS_SET_DATABASE_PROPERTY('derby.database.sqlAuthorization','TRUE');
CALL SYSCS_UTIL.SYSCS_SET_DATABASE_PROPERTY('derby.user.dvd', $DVD_PASSWORD);
DROP TABLE DVD.DISKS;
DROP SCHEMA DVD RESTRICT;
CREATE SCHEMA DVD AUTHORIZATION dvd;
CREATE TABLE DVD.DISKS (title VARCHAR(64), season INTEGER, casenumbers VARCHAR(256), tv CHAR(1), url VARCHAR(64), PRIMARY KEY(title,season));
exit
EOF2


